@@ -6,7 +6,7 @@ use Getopt::Long qw/GetOptionsFromArray :config no_auto_abbrev no_ignore_case/;
 use Mojo::JSON qw/decode_json/;
 use Mojo::Util qw/dumper tablify/;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 has description => 'Manage Minion jobs';
 has usage => sub { shift->extract_usage };
@@ -62,12 +62,13 @@ sub run {
 sub _list_jobs {
   my $jobs = shift->app->minion->backend->list_jobs(@_);
   my @job_rows;
+  push @job_rows, ['id','state','queue','created','started','finished','task'];
   foreach my $job (@$jobs) {
-      foreach my $key (qw/started finished/) {
+      foreach my $key (qw/created started finished/) {
          $job->{$key} = '[' .  localtime($job->{$key}) . ']' if defined($job->{$key});
          $job->{$key} = 'N/A' unless defined($job->{$key});
       }
-      push @job_rows, [$job->{id}, $job->{state}, $job->{queue}, $job->{started}, $job->{finished}, $job->{task}];
+      push @job_rows, [$job->{id}, $job->{state}, $job->{queue}, $job->{created}, $job->{started}, $job->{finished}, $job->{task}];
   }
   print tablify \@job_rows;
 }
@@ -207,6 +208,10 @@ L<Mojolicious::Command> and implements the following new ones.
   $job->run(@ARGV);
    
   Run this command.
+
+=head1 TO DO
+
+ - Allow command line option to let user pick which timestamps are included in the list of jobs
    
 =head1 SEE ALSO
  
